
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  require_out
} from "./chunk-AVWFCGVE.js";
import {
  getPrerenderManifest
} from "./chunk-FQII764Q.js";
import {
  SERVER_HANDLER_DIR
} from "./chunk-FSAVFRLT.js";
import {
  __toESM
} from "./chunk-RSKIKBZH.js";

// src/build/content/server.ts
var import_fast_glob = __toESM(require_out(), 1);
import { existsSync } from "node:fs";
import { cp, mkdir, readFile, readdir, readlink, symlink, writeFile } from "node:fs/promises";
import { join, resolve } from "node:path";
var copyNextServerCode = async ({
  constants: { PUBLISH_DIR }
}) => {
  const srcDir = resolve(PUBLISH_DIR, "standalone/.next");
  const destDir = resolve(SERVER_HANDLER_DIR, ".next");
  const paths = await (0, import_fast_glob.default)([`*`, `server/*`, `server/chunks/*`, `server/+(app|pages)/**/*.js`], {
    cwd: srcDir,
    extglob: true
  });
  await Promise.all(
    paths.map(async (path) => {
      await cp(join(srcDir, path), join(destDir, path), { recursive: true });
    })
  );
};
async function recreateNodeModuleSymlinks(src, dest, org) {
  const dirents = await readdir(join(src, org || ""), { withFileTypes: true });
  await Promise.all(
    dirents.map(async (dirent) => {
      if (dirent.name.startsWith("@")) {
        return recreateNodeModuleSymlinks(src, dest, dirent.name);
      }
      if (dirent.isSymbolicLink()) {
        const symlinkSrc = join(dest, org || "", dirent.name);
        const symlinkTarget = await readlink(join(src, org || "", dirent.name));
        const symlinkDest = join(dest, org || "", symlinkTarget);
        if (existsSync(symlinkDest) && !existsSync(symlinkSrc)) {
          if (org) {
            await mkdir(join(dest, org), { recursive: true });
          }
          await symlink(symlinkDest, symlinkSrc);
        }
      }
    })
  );
}
var copyNextDependencies = async ({
  constants: { PUBLISH_DIR }
}) => {
  const srcDir = resolve(PUBLISH_DIR, "standalone/node_modules");
  const destDir = resolve(SERVER_HANDLER_DIR, "node_modules");
  await cp(srcDir, destDir, { recursive: true });
  await recreateNodeModuleSymlinks(resolve("node_modules"), destDir);
};
var writeTagsManifest = async ({
  constants: { PUBLISH_DIR }
}) => {
  const manifest = await getPrerenderManifest({ PUBLISH_DIR });
  const routes = Object.entries(manifest.routes).map(async ([route, definition]) => {
    let tags;
    if (definition.dataRoute?.endsWith(".rsc")) {
      const path = resolve(PUBLISH_DIR, `server/app/${route === "/" ? "/index" : route}.meta`);
      try {
        const file = await readFile(path, "utf-8");
        const meta = JSON.parse(file);
        tags = meta.headers["x-next-cache-tags"];
      } catch (error) {
        console.log(`Unable to read cache tags for: ${path}`);
      }
    }
    if (definition.dataRoute?.endsWith(".json")) {
      tags = `_N_T_${route}`;
    }
    if (definition.dataRoute === null) {
      tags = definition.initialHeaders?.["x-next-cache-tags"];
    }
    return [route, tags];
  });
  await writeFile(
    resolve(resolve(SERVER_HANDLER_DIR, ".netlify/tags-manifest.json")),
    JSON.stringify(Object.fromEntries(await Promise.all(routes))),
    "utf-8"
  );
};

export {
  copyNextServerCode,
  copyNextDependencies,
  writeTagsManifest
};
