
      const require = await (async () => {
        const { createRequire } = await import("node:module");
        return createRequire(import.meta.url);
      })();
    
import {
  require_out
} from "./chunk-AVWFCGVE.js";
import {
  getPrerenderManifest
} from "./chunk-FQII764Q.js";
import {
  BLOB_DIR
} from "./chunk-FSAVFRLT.js";
import {
  __toESM
} from "./chunk-RSKIKBZH.js";

// src/build/content/prerendered.ts
var import_fast_glob = __toESM(require_out(), 1);
import { Buffer } from "node:buffer";
import { existsSync } from "node:fs";
import { mkdir, readFile, writeFile } from "node:fs/promises";
import { dirname, resolve } from "node:path";
var writeCacheEntry = async (key, value) => {
  const path = resolve(BLOB_DIR, Buffer.from(key).toString("base64"));
  const entry = JSON.stringify({
    lastModified: Date.now(),
    value
  });
  await mkdir(dirname(path), { recursive: true });
  await writeFile(path, entry, "utf-8");
};
var routeToFilePath = (path) => path.replace(/^\//, "") || "index";
var buildPagesCacheValue = async (path) => ({
  kind: "PAGE",
  html: await readFile(`${path}.html`, "utf-8"),
  pageData: JSON.parse(await readFile(`${path}.json`, "utf-8"))
});
var buildAppCacheValue = async (path) => ({
  kind: "PAGE",
  html: await readFile(`${path}.html`, "utf-8"),
  pageData: await readFile(`${path}.rsc`, "utf-8"),
  ...JSON.parse(await readFile(`${path}.meta`, "utf-8"))
});
var buildRouteCacheValue = async (path) => ({
  kind: "ROUTE",
  body: await readFile(`${path}.body`, "utf-8"),
  ...JSON.parse(await readFile(`${path}.meta`, "utf-8"))
});
var buildFetchCacheValue = async (path) => ({
  kind: "FETCH",
  ...JSON.parse(await readFile(path, "utf-8"))
});
var copyPrerenderedContent = async ({
  constants: { PUBLISH_DIR },
  utils: {
    build: { failBuild }
  }
}) => {
  try {
    const manifest = await getPrerenderManifest({ PUBLISH_DIR });
    await Promise.all(
      Object.entries(manifest.routes).map(async ([route, meta]) => {
        const key = routeToFilePath(route);
        let value;
        switch (true) {
          case meta.dataRoute?.endsWith(".json"):
            value = await buildPagesCacheValue(resolve(PUBLISH_DIR, "server/pages", key));
            break;
          case meta.dataRoute?.endsWith(".rsc"):
            value = await buildAppCacheValue(resolve(PUBLISH_DIR, "server/app", key));
            break;
          case meta.dataRoute === null:
            value = await buildRouteCacheValue(resolve(PUBLISH_DIR, "server/app", key));
            break;
          default:
            throw new Error(`Unrecognized content: ${route}`);
        }
        await writeCacheEntry(key, value);
      })
    );
    if (existsSync(resolve(PUBLISH_DIR, `server/app/_not-found.html`))) {
      const key = "404";
      const value = await buildAppCacheValue(resolve(PUBLISH_DIR, "server/app/_not-found"));
      await writeCacheEntry(key, value);
    }
  } catch (error) {
    failBuild(
      "Failed assembling prerendered content for upload",
      error instanceof Error ? { error } : {}
    );
  }
};
var copyFetchContent = async ({
  constants: { PUBLISH_DIR },
  utils: {
    build: { failBuild }
  }
}) => {
  try {
    const paths = await (0, import_fast_glob.default)(["!(*.*)"], {
      cwd: resolve(PUBLISH_DIR, "cache/fetch-cache"),
      extglob: true
    });
    await Promise.all(
      paths.map(async (key) => {
        const value = await buildFetchCacheValue(resolve(PUBLISH_DIR, "cache/fetch-cache", key));
        await writeCacheEntry(key, value);
      })
    );
  } catch (error) {
    failBuild("Failed assembling fetch content for upload", error instanceof Error ? { error } : {});
  }
};

export {
  copyPrerenderedContent,
  copyFetchContent
};
